.. _contributing:

Contributing to Weblate
=======================


There are dozens of ways to improve Weblate. You can choose the one you feel comfortable with, be it
coding, graphics design, documentation, sponsorship, or an idea:

* :doc:`issues`
* :doc:`start`
* :ref:`translating-weblate`
* :ref:`contributing-docs`
* :ref:`discussions`
* :ref:`funding-weblate`

.. _translating-weblate:

Translating Weblate
-------------------

Weblate is continually being `translated <https://hosted.weblate.org/>`_ using Weblate itself. Feel
free to take your part in the effort of making Weblate available in as many human languages
as possible. It brings Weblate closer to its users!

If you find a possible mistake in the source string, you can mark it with a comment in the Weblate editor.
This way, it can be discussed and corrected. If you’re certain, you can also click on the link in the
:guilabel:`Source string location` section and submit a PR with your correction.

.. _contributing-docs:

Contribute to Weblate documentation
-----------------------------------

You are welcome to improve the documentation page of your choice.
Do it easily by clicking the :guilabel:`Edit on GitHub` button in the top-right corner of the page.

Please respect these guidelines while writing:

 1. Don’t remove part of the documentation if it’s valid.
 2. Use clear and easily-understandable language. You are writing tech docs, not a poem.
    Not all docs readers are native speakers, be thoughtful.
 3. Don’t be affraid to ask if you are not certain.
    If you have to ask about some feature while editing, don’t change its docs before you have the answer.
    This means: You change or ask. Don’t do both at the same time.
 4. Verify your changes by performing described actions while following the docs.
 5. Send PR with changes in small chunks to make it easier and quicker to review and merge.
 6. If you want to rewrite and change the structure of a big article, do it in two steps:

    1. Rewrite
    2. Once the rewrite is reviewed, polished, and merged, change the structure of the paragraphs in another PR.

.. hint::

    You can `translate the docs <https://hosted.weblate.org/projects/weblate/documentation/>`_.


.. _extending-lanugages:

Extending built-in language definitions
---------------------------------------

The language definitions are in the `weblate-language-data repository
<https://github.com/WeblateOrg/language-data/>`_.

You are welcome to add missing language definitions to :file:`languages.csv`,
other files are generated from that file.

.. _discussions:

Weblate discussions
-------------------

If you have an idea and not sure if it’s suitable for an issue, don’t worry.
You can join the community in `GitHub discussions <https://github.com/WeblateOrg/weblate/discussions>`_.


.. _funding-weblate:

Funding Weblate development
---------------------------

You can boost Weblate’s development on the `donate page`_. Funds collected
there are used to enable gratis hosting for libre software projects and further
development of Weblate.
Please check the `donate page`_ for options, such
as funding goals and the rewards you get as a proud funder.

.. include:: ../../BACKERS.rst


.. _donate page: https://weblate.org/donate/
